=======
Credits
=======

Development Lead
----------------
Ed Coen <https://github.com/ecoen66>

Based on Work by
----------------
* Fady Sharobeem <https://github.com/fadysharobeem>

* Hank Preston <https://github.com/hpreston>
* Josh Anderson <https://github.com/joshand>
* Oleksii Borisenko <https://github.com/oborys>
